==> dnet-openaireplus-workflows-0.0.1-20140124.100305-192-sources.jar: eu/dnetlib/msro/openaireplus/workflows/nodes/FindExistingRepositoriesJobNode.java <==
package eu.dnetlib.msro.openaireplus.workflows.nodes;

import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import com.google.common.collect.Maps;
import com.googlecode.sarasvati.Arc;
import com.googlecode.sarasvati.NodeToken;

import eu.dnetlib.enabling.is.lookup.rmi.ISLookUpService;
import eu.dnetlib.enabling.tools.ServiceLocator;
import eu.dnetlib.msro.workflows.nodes.SimpleJobNode;

public class FindExistingRepositoriesJobNode extends SimpleJobNode {
	
	@Resource(name="lookupLocator")
	private ServiceLocator<ISLookUpService> lookupLocator;

	private String existingReposParam = "existingRepos";
	
	class RepositoryInfo {
		public String resourceKind;
		public String repoId;

		public RepositoryInfo(String resourceKind, String repoId) {
			this.resourceKind = resourceKind;
			this.repoId = repoId;
		}
		@Override
		public String toString() {
			return "[" + resourceKind + ", " + repoId + "]";
		}
	}

	@Override
	protected String execute(NodeToken token) throws Exception {
		String xquery = 
				"for $x in /*[.//RESOURCE_TYPE/@value='RepositoryServiceResourceType'] " +
				"return concat (" +
				"$x//RESOURCE_IDENTIFIER/@value, " +
				"'@@@', " +
				"$x//RESOURCE_KIND/@value, " +
				"'@@@', " +
				"$x//EXTRA_FIELDS/FIELD[./key='OpenAireDataSourceId']/value)";
		final List<String> list = lookupLocator.getService().quickSearchProfile(xquery);
		
		final Map<String, RepositoryInfo> map = Maps.newHashMap();
		for (String s : list) {
			String[] arr = s.split("@@@");
			if (arr.length == 3) {
				map.put(arr[2], new RepositoryInfo(arr[1], arr[0]));
			}
		}
		token.getEnv().setTransientAttribute(getExistingReposParam(), map);
		
		return Arc.DEFAULT_ARC;
	}

	public String getExistingReposParam() {
		return existingReposParam;
	}

	public void setExistingReposParam(String existingReposParam) {
		this.existingReposParam = existingReposParam;
	}

}

==> dnet-openaireplus-workflows-2.0.1-20141114.113430-1-sources.jar: eu/dnetlib/msro/openaireplus/workflows/nodes/FindExistingRepositoriesJobNode.java <==
package eu.dnetlib.msro.openaireplus.workflows.nodes;

import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import com.google.common.collect.Maps;
import com.googlecode.sarasvati.Arc;
import com.googlecode.sarasvati.NodeToken;

import eu.dnetlib.enabling.is.lookup.rmi.ISLookUpService;
import eu.dnetlib.enabling.locators.UniqueServiceLocator;
import eu.dnetlib.msro.workflows.nodes.SimpleJobNode;

public class FindExistingRepositoriesJobNode extends SimpleJobNode {

	@Resource
	private UniqueServiceLocator serviceLocator;

	private String existingReposParam = "existingRepos";

	class RepositoryInfo {

		public String resourceKind;
		public String repoId;

		public RepositoryInfo(final String resourceKind, final String repoId) {
			this.resourceKind = resourceKind;
			this.repoId = repoId;
		}

		@Override
		public String toString() {
			return "[" + resourceKind + ", " + repoId + "]";
		}
	}

	@Override
	protected String execute(final NodeToken token) throws Exception {
		String xquery =
				"for $x in /*[.//RESOURCE_TYPE/@value='RepositoryServiceResourceType'] " +
						"return concat (" +
						"$x//RESOURCE_IDENTIFIER/@value, " +
						"'@@@', " +
						"$x//RESOURCE_KIND/@value, " +
						"'@@@', " +
						"$x//EXTRA_FIELDS/FIELD[./key='OpenAireDataSourceId']/value)";
		final List<String> list = serviceLocator.getService(ISLookUpService.class).quickSearchProfile(xquery);

		final Map<String, RepositoryInfo> map = Maps.newHashMap();
		for (String s : list) {
			String[] arr = s.split("@@@");
			if (arr.length == 3) {
				map.put(arr[2], new RepositoryInfo(arr[1], arr[0]));
			}
		}
		token.getEnv().setTransientAttribute(getExistingReposParam(), map);

		return Arc.DEFAULT_ARC;
	}

	public String getExistingReposParam() {
		return existingReposParam;
	}

	public void setExistingReposParam(final String existingReposParam) {
		this.existingReposParam = existingReposParam;
	}

}
